@@ -11,10 +11,49 @@ use Nexmo::SMS::GetBalance;
 
 # ABSTRACT: Module for the Nexmo SMS API!
 
-
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 
+=head1 SYNOPSIS
+
+This module simplifies sending SMS through the Nexmo API.
+
+
+    use Nexmo::SMS;
+
+    my $nexmo = Nexmo::SMS->new(
+        server   => 'http://rest.nexmo.com/sms/json',
+        username => 'testuser1',
+        password => 'testpasswd2',
+    );
+    
+    my $sms = $nexmo->sms(
+        text     => 'This is a test',
+        from     => 'Test02',
+        to       => '452312432',
+    ) or die $nexmo->errstr;
+    
+    my $response = $sms->send || die $sms->errstr;
+    
+    if ( $response->is_success ) {
+        print "SMS was sent...\n";
+    }
+
+=head1 METHODS
+
+=head2 new
+
+create a new object
+
+    my $foo = Nexmo::SMS->new(
+        server   => 'http://rest.nexmo.com/sms/json',
+        username => 'testuser1',
+        password => 'testpasswd2',
+    );
+
+Those parameters are optional and they are used as defaults for the message objects
+
+=cut
 
 my @attrs = qw(server username password);;
 
@@ -45,6 +84,27 @@ sub new {
     return $self;
 }
 
+=head2 sms
+
+Create a new message object or returns C<undef>.
+
+    my $sms = $nexmo->sms(
+        text     => 'This is a test',
+        from     => 'Test02',
+        to       => '452312432',
+    ) or die $nexmo->errstr;
+
+Send a binary message
+
+    my $binary = $nexmo->sms(
+        type     => 'binary',
+        udh      => '06050415811581',   # hex encoded udh
+        body     => '0011223344556677', # hex encoded body
+        from     => 'Test02',
+        to       => '452312432',
+    ) or die $nexmo->errstr;
+
+=cut
 
 sub sms {
     my ($self,%param) = @_;
@@ -92,6 +152,13 @@ sub sms {
     return $message;
 }
 
+=head2 errstr
+
+return the "last" error as string.
+
+    print $nexmo->errstr;
+
+=cut
 
 sub errstr {
     my ($self,$message) = @_;
@@ -100,6 +167,11 @@ sub errstr {
     return $self->{__errstr__};
 }
 
+=head2 get_balance
+
+  my $balance = $nexmo->get_balance;
+
+=cut
 
 sub get_balance {
     my ($self,%param) = @_;
@@ -115,102 +187,17 @@ sub get_balance {
     return $balance->get_balance;
 }
 
+=head2 get_pricing
+
+Not implemented yet...
+
+=cut
 
 sub get_pricing {
     warn "not implemented yet\n";
     return;
 }
 
-
-1; # End of Nexmo::SMS
-
-__END__
-=pod
-
-=head1 NAME
-
-Nexmo::SMS - Module for the Nexmo SMS API!
-
-=head1 VERSION
-
-version 0.06
-
-=head1 SYNOPSIS
-
-This module simplifies sending SMS through the Nexmo API.
-
-    use Nexmo::SMS;
-
-    my $nexmo = Nexmo::SMS->new(
-        server   => 'http://rest.nexmo.com/sms/json',
-        username => 'testuser1',
-        password => 'testpasswd2',
-    );
-    
-    my $sms = $nexmo->sms(
-        text     => 'This is a test',
-        from     => 'Test02',
-        to       => '452312432',
-    ) or die $nexmo->errstr;
-    
-    my $response = $sms->send || die $sms->errstr;
-    
-    if ( $response->is_success ) {
-        print "SMS was sent...\n";
-    }
-
-=head1 VERSION
-
-Version 0.06
-
-=head1 METHODS
-
-=head2 new
-
-create a new object
-
-    my $foo = Nexmo::SMS->new(
-        server   => 'http://rest.nexmo.com/sms/json',
-        username => 'testuser1',
-        password => 'testpasswd2',
-    );
-
-Those parameters are optional and they are used as defaults for the message objects
-
-=head2 sms
-
-Create a new message object or returns C<undef>.
-
-    my $sms = $nexmo->sms(
-        text     => 'This is a test',
-        from     => 'Test02',
-        to       => '452312432',
-    ) or die $nexmo->errstr;
-
-Send a binary message
-
-    my $binary = $nexmo->sms(
-        type     => 'binary',
-        udh      => '06050415811581',   # hex encoded udh
-        body     => '0011223344556677', # hex encoded body
-        from     => 'Test02',
-        to       => '452312432',
-    ) or die $nexmo->errstr;
-
-=head2 errstr
-
-return the "last" error as string.
-
-    print $nexmo->errstr;
-
-=head2 get_balance
-
-  my $balance = $nexmo->get_balance;
-
-=head2 get_pricing
-
-Not implemented yet...
-
 =head1 Attributes
 
 These attributes are available for C<Nexmo::SMS::TextMessage> objects. For each
@@ -229,66 +216,11 @@ attribute there is a getter/setter:
 
 =back
 
-=head1 AUTHOR
-
-Renee Baecker, C<< <module at renee-baecker.de> >>
-
-=head1 BUGS
-
-Please report any bugs or feature requests to C<bug-nexmo-sms at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Nexmo-SMS>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc Nexmo::SMS
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Nexmo-SMS>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Nexmo-SMS>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Nexmo-SMS>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/Nexmo-SMS/>
-
-=back
-
 =head1 ACKNOWLEDGEMENTS
 
 Jui-Nan Lin added support for Unicode messages, thanks!
 (see https://github.com/reneeb/perl-Nexmo-SMS/pull/1/files)
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2011 Renee Baecker.
-
-This program is released under the following license: artistic_2
-
-=head1 AUTHOR
-
-Renee Baecker <module@renee-baecker.de>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2011 by Renee Baecker.
-
-This is free software, licensed under:
-
-  The Artistic License 2.0 (GPL Compatible)
-
 =cut
 
+1; # End of Nexmo::SMS
