@@ -5,7 +5,6 @@ use warnings;
 
 # ABSTRACT: Module that represents a single message in the response from Nexmo SMS API!
 
-
 our $VERSION = '0.02';
 
 # create getter/setter
@@ -41,6 +40,45 @@ my %status_map = (
     12 => [ 'Message too long',	'Applies to Binary submissions, where the length of the UDF and the message body combined exceed 140 octets' ],
 );
 
+=head1 SYNOPSIS
+
+This module represents a single message in a response from Nexmo.
+
+
+    use Nexmo::SMS::Response::Message;
+
+    my $nexmo = Nexmo::SMS::Response::Message->new(
+        json => '{
+              "status":"4",
+              "message-id":"message001",
+              "client-ref":"Test001 - Reference",
+              "remaining-balance":"20.0",
+              "message-price":"0.05",
+              "error-text":""
+              }',
+    );
+    
+    print $nexmo->message_price;
+
+=head1 METHODS
+
+=head2 new
+
+create a new object
+
+    my $foo = Nexmo::SMS::Response::Message->new(
+        json => '
+              {
+              "status":"4",
+              "message-id":"message001",
+              "client-ref":"Test001 - Reference",
+              "remaining-balance":"20.0",
+              "message-price":"0.05",
+              "error-text":""
+              }',
+    );
+
+=cut
 
 sub new {
     my ($class,%param) = @_;
@@ -65,59 +103,6 @@ sub new {
 
 1;
 
-
-__END__
-=pod
-
-=head1 NAME
-
-Nexmo::SMS::Response::Message - Module that represents a single message in the response from Nexmo SMS API!
-
-=head1 VERSION
-
-version 0.06
-
-=head1 SYNOPSIS
-
-This module represents a single message in a response from Nexmo.
-
-    use Nexmo::SMS::Response::Message;
-
-    my $nexmo = Nexmo::SMS::Response::Message->new(
-        json => '{
-              "status":"4",
-              "message-id":"message001",
-              "client-ref":"Test001 - Reference",
-              "remaining-balance":"20.0",
-              "message-price":"0.05",
-              "error-text":""
-              }',
-    );
-    
-    print $nexmo->message_price;
-
-=head1 VERSION
-
-Version 0.02
-
-=head1 METHODS
-
-=head2 new
-
-create a new object
-
-    my $foo = Nexmo::SMS::Response::Message->new(
-        json => '
-              {
-              "status":"4",
-              "message-id":"message001",
-              "client-ref":"Test001 - Reference",
-              "remaining-balance":"20.0",
-              "message-price":"0.05",
-              "error-text":""
-              }',
-    );
-
 =head1 ATTRIBUTES
 
 These attributes are available for C<Nexmo::SMS::TextMessage> objects:
@@ -143,25 +128,3 @@ These attributes are available for C<Nexmo::SMS::TextMessage> objects:
 
 =back
 
-=head1 ACKNOWLEDGEMENTS
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2011 Renee Baecker.
-
-This program is released under the following license: artistic_2
-
-=head1 AUTHOR
-
-Renee Baecker <module@renee-baecker.de>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2011 by Renee Baecker.
-
-This is free software, licensed under:
-
-  The Artistic License 2.0 (GPL Compatible)
-
-=cut
-
